pub struct QueueItem<'basedir, V: DeserializeOwned + Serialize + 'static> { /* private fields */ }Expand description
The self-referencing struct.
Implementations
Sourceimpl<'basedir, V: DeserializeOwned + Serialize> QueueItem<'basedir, V>
impl<'basedir, V: DeserializeOwned + Serialize> QueueItem<'basedir, V>
pub fn from_entry<'s>( entry: Entry<'s, TimeKey, V>, base_dir: &PathBuf, opts: QueueGetItemOptions, ) -> Result<QueueItem<'s, V>, KeyValError>
Sourcepub fn key(&self) -> Result<TimeKey, KeyValError>
pub fn key(&self) -> Result<TimeKey, KeyValError>
Get the key inside this queue, usable with get_entry
(careful, there is no check against using it in the wrong
queue!)
Sourcepub fn delete(&self) -> Result<(), KeyValError>
pub fn delete(&self) -> Result<(), KeyValError>
Delete this item now (alternatively, give delete_first in
QueueIterationOptions)
Sourcepub fn lock_exclusive<'s>(
&'s self,
) -> Result<ExclusiveFileLock<'s, File>, KeyValError>
pub fn lock_exclusive<'s>( &'s self, ) -> Result<ExclusiveFileLock<'s, File>, KeyValError>
Lock this item lazily (when no_lock == true given, but now a
lock is needed). If no_lock was false, then this gives a
KeyValError::AlreadyLocked error rather than dead-locking.